pub enum AssignmentSource {
Occurrence,
Type(EntityId),
}Expand description
Whether a resolved material assignment came from the object directly or
was inherited from its IfcTypeObject.
Variants
Occurrence
The IfcRelAssociatesMaterial directly relates the queried object.
Type(EntityId)
The IfcRelAssociatesMaterial relates the object’s IfcTypeObject,
identified by this entity id, and was inherited from it.